@@ -1,6 +1,6 @@
 from typing import List, Union
 
-from pyblaze.models.crash import CurrentBet
+from pyblaze.models.crash import Bet
 from pydantic import BaseModel
 
 
@@ -9,4 +9,4 @@ class CurrentResponse(BaseModel):
     total_eur_bet: float
     total_bets_placed: int
     total_eur_won: Union[float, None]
-    bets: List[CurrentBet]
+    bets: List[Bet]
